GreenVideoChannels class

This is the default implementation of GreenVideoPlatform which uses a MethodChannel and an EventChannel to fulfill the communication flow as described by the extended class.

Inheritance

Constructors

GreenVideoChannels()

Properties

getPlayerEvents Stream<Map<Object?, Object?>>
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose(int viewId) → void
inherited
enterFullscreen(int viewId) → void
override
exitFullscreen(int viewId) → void
override
hideUi(int viewId) → void
override
mute(int viewId) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause(int viewId) → void
override
play(int viewId) → void
override
seek(int viewId, double position) → void
override
seekBackward(int viewId, double time) → void
override
seekForward(int viewId, double time) → void
override
showUi(int viewId) → void
override
startContent(int viewId) → void
override
startNextContent(int viewId) → void
override
startPreviousContent(int viewId) → void
override
toString() String
A string representation of this object.
inherited
unmute(int viewId) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited