GreenVideo class

This is the main Widget for the GreenVideo video player

To create this Widget, you must pass at least your licenseKey and your embedId. All other fields are optional.

Beside the widget fields, you can also pass functions for several player events.

This Widget will try to take as much screen estate as possible. So it is up to the developer to define the bounding box for it in the UI.

Inheritance

Constructors

GreenVideo({Key? key, double? width, double? height, double? aspectRatio, required String licenseKey, required String embedId, String? mixId, String? contentId, String? adTagUrl, String? consentString, bool? adsDisallowed, String? environment, bool? debug, GreenVideoController? controller})

Properties

adsDisallowed bool?
final
adTagUrl String?
final
aspectRatio double?
final
consentString String?
final
contentId String?
final
controller GreenVideoController?
final
debug bool?
final
embedId String
final
environment String?
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
licenseKey String
final
mixId String?
final
playerId String
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
dispose() → void
getWrappedWidget(Widget content, double? width, double? height, double? aspectRatio) Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited