SnapFrameOverlay class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- SnapFrameOverlay
Constructors
- SnapFrameOverlay({required GreenVideoController? controller, EdgeInsetsGeometry padding = const EdgeInsets.all(10.0), Color borderColor = Colors.red, double borderWidth = 4.0, double cornerInset = 8.0, AlignmentGeometry cornerAlignment = Alignment.bottomRight, double cornerWidth = 200.0, double? cornerHeight, Key? key})
-
const
Properties
- borderColor → Color
-
final
- borderWidth → double
-
final
- controller → GreenVideoController?
-
final
- cornerAlignment → AlignmentGeometry
-
final
- cornerHeight → double?
-
final
- cornerInset → double
-
final
- cornerWidth → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- padding → EdgeInsetsGeometry
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< SnapFrameOverlay> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited